==> deverhood-react-1.16.51.tgz: package/src/sagas/user.js <==
import {
  COMPONENT,
  GET,
  POST,
  PUT,
  DEL,
  ALL,
  USER_REQUEST,
  USER_API,
  SELF,
  REDIRECT_TO,
  SIGNUP,
  CLEAR,
  SEARCH,
  INSTITUTE,
  VERIFY,
  VERIFY_CODE,
  ME,
  EXTERNAL_SIGNUP,
  FORGOT,
  RESET,
  PREDEFINED,
  PASSWORD,
  IMPORT,
  USER
} from "../actions/actionType.js";
import { put, fork, call, take, takeEvery, throttle } from "redux-saga/effects";
import user from "../services/user";
import graphql from "../services/graphql";
const url = "account";
import query from "query";
const convert = item => {
  return JSON.stringify(item).replace(/\"([^(\")"]+)\":/g, "$1:");
};
function* callback(isSuccess, error) {
  isSuccess
    ? yield put({
        type: COMPONENT.CALLBACK_SUCCESS
      })
    : yield put({
        type: COMPONENT.CALLBACK_FAIL,
        data: error.response.data.message
      });
  yield put({
    type: COMPONENT.SUCCESS
  });
}
function* loading() {
  yield put({
    type: COMPONENT.CALLBACK_LOADING
  });
}
function* complete() {
  yield put({
    type: COMPONENT.SUCCESS
  });
}
function* outOfRange() {
  yield put({
    type: COMPONENT.CALLBACK_OUT
  });
}
function* renew() {
  yield put({
    type: COMPONENT.CALLBACK_NEW
  });
}
function* request(actions) {
  switch (actions.api) {
    case GET:
      return yield fork(get, actions);
    case POST:
      return yield fork(post, actions);
    case PUT:
      return yield fork(change, actions);
    case DEL:
      return yield fork(del, actions);
    case ALL:
      return yield fork(getAll, actions);
    case CLEAR:
      return yield fork(clear, actions);
    case SEARCH:
      return yield fork(search, actions);
    default:
      null;
  }
}
function* clear(actions) {
  switch (actions.doc) {
    case SIGNUP:
      return yield put({
        type: USER_API.SIGNUP.CLEAR.SUCCESS
      });
    case SELF:
      return yield put({
        type: USER_API.SELF.CLEAR.SUCCESS
      });
    default:
      break;
  }
}
function* getAll(actions) {
  try {
    switch (actions.doc) {
      case SELF:
        yield call(loading);
        var response = yield call(
          graphql.search,
          "users",
          actions.obj ? actions.obj.skip : 0,
          actions.obj ? actions.obj.limit : 10,
          url,
          actions
        );
        var users = response.data.data.users;
        yield put({
          type: USER_API.SELF.ALL.SUCCESS,
          data: users
        });
        if (users.length == 0) {
          return yield call(outOfRange);
        } else {
          return yield call(complete);
        }
        
      case PREDEFINED:
        yield call(loading);
        var response = yield call(
          graphql.search,
          "predefinedAccounts",
          actions.obj ? actions.obj.skip : 0,
          actions.obj ? actions.obj.limit : 10,
          url,
          actions
        );
        var users = response.data.data.predefinedAccounts;
        yield put({
          type: USER_API.PREDEFINED.ALL.SUCCESS,
          data: users
        });
        if (users.length == 0) {
          return yield call(outOfRange);
        } else {
          return yield call(complete);
        }
      case SIGNUP:
        yield call(loading);
        var response = yield call(user.listPending, actions.item);
        var pendings = response.data;
        yield put({
          type: USER_API.SIGNUP.ALL.SUCCESS,
          data: pendings
        });
        return yield call(complete);
      case INSTITUTE:
        yield call(loading);
        var response = yield call(user.listInistute);
        yield put({
          type: USER_API.INSTITUTE.ALL.SUCCESS,
          data: response.data
        });
        return yield call(complete);
      default:
        null;
    }
  } catch (e) {
    console.log(e);
    //yield call(callback, false, e);
  }
}
function* get(actions) {
  try {
    switch (actions.doc) {
      case ME:
        var response = yield call(graphql.get, "me", "account", actions);
        if (response.data) {
          return yield put({
            type: USER_API.ME.GET.SUCCESS,
            data: response.data.data.me
          });
        } else {
          return yield call({ type: REDIRECT_TO, redirectTo: "/login" });
        }
      case SELF:
        var response = yield call(user.getUser, actions.id);
        return yield put({
          type: USER_API.SELF.GETID.SUCCESS,
          data: response.data
        });
        return yield call(callback, true);
      case PREDEFINED:
        var response = yield call(
          graphql.get,
          `predefinedAccount(id:"${actions.id}")`,
          url,
          actions
        );
        return yield put({
          type: USER_API.PREDEFINED.GET.SUCCESS,
          data: response.data.data.predefinedAccount
        });
        return yield call(callback, true);
      case SIGNUP:
        var response = yield call(user.getPending, actions.id);
        return yield put({
          type: USER_API.SIGNUP.GET.SUCCESS,
          data: response.data
        });
        return yield call(callback, true);
      case VERIFY:
        yield call(loading);
        var response = yield call(user.getVerify, actions.item);
        yield put({
          type: USER_API.VERIFY.GET.SUCCESS,
          data: response.data
        });
        return yield call(callback, true);
      case VERIFY_CODE:
        yield call(loading);
        var response = yield call(user.getVerifyCode, actions.id);
        yield put({
          type: USER_API.VERIFY_CODE.GET.SUCCESS,
          data: response.data
        });
        return yield call(callback, true);
      default:
        null;
    }
  } catch (e) {
    console.log(e);
    if (actions.doc === "ME") {
      yield put({
        type: REDIRECT_TO,
        redirectTo: "/login"
      });
    } else {
      yield call(callback, false, e);
    }
  }
}
function* post(actions) {
  try {
    switch (actions.doc) {
      case SELF:
        var response = yield call(user.postUser, actions.item);
        yield put({
          type: USER_API.SELF.POST.SUCCESS,
          data: response.data
        });
        yield call(callback, true);
        return yield put({
          type: REDIRECT_TO,
          redirectTo: "/user"
        });
      case SIGNUP:
        var response = yield call(user.signup, actions.item);
        yield put({
          type: USER_API.SIGNUP.POST.SUCCESS,
          data: response.data
        });
        yield call(callback, true);
        return yield put({
          type: REDIRECT_TO,
          redirectTo: "/login"
        });
      case EXTERNAL_SIGNUP:
        var response = yield call(user.externalSignup, actions.item);
        yield put({
          type: USER_API.EXTERNAL_SIGNUP.POST.SUCCESS,
          data: response.data
        });
        call(callback, true);
        return yield put({
          type: REDIRECT_TO,
          redirectTo: "/"
        });
      case VERIFY:
        var response = yield call(user.signupVerify, actions.item);
        yield put({
          type: USER_API.VERIFY.POST.SUCCESS,
          data: response.data
        });
        return yield call(callback, true);
      case FORGOT:
        var response = yield call(
          graphql.import,
          `/account/password/forgot/${actions.item.username}`,
          actions.item
        );
        yield put({
          type: USER_API.FORGOT.POST.SUCCESS,
          data: response.data
        });
        yield call(callback, true);
        return yield put({
          type: REDIRECT_TO,
          redirectTo: "/login"
        });
      case RESET:
        var response = yield call(
          graphql.import,
          `/account/password/reset?resetKey=${actions.item.resetKey}`,
          `${actions.item.password}`
        );
        yield put({
          type: USER_API.RESET.POST.SUCCESS,
          data: response.data
        });
        yield call(callback, true);
        return yield put({
          type: REDIRECT_TO,
          redirectTo: "/login"
        });
      case IMPORT:
        var response = yield call(
          graphql.graph,
          `mutation{
  insertUserMany(roles:["${actions.obj.role}"],specialtyId:"${
            actions.obj.specialtyId
          }",users:${convert(actions.item)}){
    problem
    user{
      username

      email
      titleTh
      firstNameTh
      lastNameTh
      titleEn
      firstNameEn
      lastNameEn
      gender
      phoneNumber
      yearEnrolled
    }
  }
}`,
          {},
          url,
          actions
        );
        yield put({
          type: USER_API.IMPORT.POST.SUCCESS,
          data: response.data.data.insertUserMany
        });
        return yield call(callback, true);

      default:
        null;
    }
  } catch (e) {
    console.log(e);
    yield call(callback, false, e);
  }
}
function* change(actions) {
  try {
    switch (actions.doc) {
      case SELF:
        var response = yield call(user.putUser, actions.id, actions.item);
        yield put({
          type: USER_API.SELF.PUT.SUCCESS,
          data: response.data
        });
        yield put({
          type: USER_API.ME.GET.SUCCESS,
          data: response.data
        });
        return yield call(callback, true);
      case SIGNUP:
        var response = yield call(user.putPending, actions.id, actions.item);
        yield put({
          type: USER_API.SIGNUP.PUT.SUCCESS,
          data: response.data
        });
        yield call(callback, true);
        return yield put({
          type: REDIRECT_TO,
          redirectTo: "/user/pending"
        });
      case PREDEFINED:
        var response = yield call(
          graphql.put,
          `PredefinedAccount`,
          url,
          actions
        );
        yield put({
          type: USER_API.PREDEFINED.PUT.SUCCESS,
          data: response.data
        });
        return yield call(callback, true);
      case PASSWORD:
        var response = yield call(
          graphql.postRest,
          `/api/account/password/change/${actions.id}`,
          actions.item
        );
        yield put({
          type: USER_API.PASSWORD.PUT.SUCCESS,
          data: response.data
        });
        return yield call(callback, true);
      default:
        null;
    }
  } catch (e) {
    console.log(e);
    yield call(callback, false, e);
  }
}
function* del(actions) {
  try {
    switch (actions.doc) {
      case SELF:
        var response = yield call(user.delUser, actions.id);
        yield put({
          type: USER_API.SELF.DEL.SUCCESS,
          data: actions.id
        });
        yield call(callback, true);
        return yield put({
          type: REDIRECT_TO,
          redirectTo: "/user"
        });
      case SIGNUP:
        var response = yield call(user.delPending, actions.id);
        yield put({
          type: USER_API.SIGNUP.DEL.SUCCESS,
          data: actions.id
        });
        yield call(callback, true);
        return yield put({
          type: REDIRECT_TO,
          redirectTo: "/user/pending"
        });
      case PREDEFINED:
        var response = yield call(
          graphql.delete,
          `PredefinedAccount`,
          url,
          actions
        );
        yield put({
          type: USER_API.PREDEFINED.DEL.SUCCESS,
          data: actions.id
        });
        yield call(callback, true);
        return yield put({
          type: REDIRECT_TO,
          redirectTo: "/user/nonMember"
        });
      default:
        null;
    }
  } catch (e) {
    console.log(e);
    yield call(callback, false, e);
  }
}
function* search(actions) {
  try {
    switch (actions.doc) {
      case SELF:
        var response = yield call(
          graphql.search,
          "users",
          actions.item.skip,
          actions.obj ? (actions.obj.limit ? actions.obj.limit : 30) : 30,
          "account",
          actions
        );
        return yield put({
          type: USER_API.SELF.SEARCH.SUCCESS,
          data: response.data.data.users
        });
      case INSTITUTE:
        var response = yield call(
          graphql.search,
          "instituteUsers",
          actions.item.skip,
          actions.obj ? (actions.obj.limit ? actions.obj.limit : 30) : 30,
          "account",
          actions
        );
        return yield put({
          type: USER_API.SELF.SEARCH.SUCCESS,
          data: response.data.data.instituteUsers
        });
      default:
        null;
    }
  } catch (e) {
    console.log(e);
    yield call(callback, false, e);
  }
}
export function* watchUser() {
  yield takeEvery(USER_REQUEST, request);
}

==> deverhood-react-1.16.59.tgz: package/src/sagas/user.js <==
import {
  COMPONENT,
  GET,
  POST,
  PUT,
  DEL,
  ALL,
  USER_REQUEST,
  USER_API,
  SELF,
  REDIRECT_TO,
  SIGNUP,
  CLEAR,
  SEARCH,
  INSTITUTE,
  VERIFY,
  VERIFY_CODE,
  ME,
  EXTERNAL_SIGNUP,
  FORGOT,
  RESET,
  PREDEFINED,
  PASSWORD,
  IMPORT,
  USER,
  STUDENT,
  STAT
} from "../actions/actionType.js";
import { put, fork, call, take, takeEvery, throttle } from "redux-saga/effects";
import user from "../services/user";
import graphql from "../services/graphql";
const url = "account";
import query from "query";
import roles from "roles";
const convert = item => {
  return JSON.stringify(item).replace(/\"([^(\")"]+)\":/g, "$1:");
};
function* callback(isSuccess, error) {
  isSuccess
    ? yield put({
        type: COMPONENT.CALLBACK_SUCCESS
      })
    : yield put({
        type: COMPONENT.CALLBACK_FAIL,
        data: error.response.data.message
      });
  yield put({
    type: COMPONENT.SUCCESS
  });
}
function* loading() {
  yield put({
    type: COMPONENT.CALLBACK_LOADING
  });
}
function* complete() {
  yield put({
    type: COMPONENT.SUCCESS
  });
}
function* outOfRange() {
  yield put({
    type: COMPONENT.CALLBACK_OUT
  });
}
function* renew() {
  yield put({
    type: COMPONENT.CALLBACK_NEW
  });
}
function* request(actions) {
  switch (actions.api) {
    case GET:
      return yield fork(get, actions);
    case POST:
      return yield fork(post, actions);
    case PUT:
      return yield fork(change, actions);
    case DEL:
      return yield fork(del, actions);
    case ALL:
      return yield fork(getAll, actions);
    case CLEAR:
      return yield fork(clear, actions);
    case SEARCH:
      return yield fork(search, actions);
    default:
      null;
  }
}
function* clear(actions) {
  switch (actions.doc) {
    case SIGNUP:
      return yield put({
        type: USER_API.SIGNUP.CLEAR.SUCCESS
      });
    case SELF:
      return yield put({
        type: USER_API.SELF.CLEAR.SUCCESS
      });
    case INSTITUTE:
      return yield put({
        type: USER_API.INSTITUTE.CLEAR.SUCCESS
      });
    default:
      break;
  }
}
function* getAll(actions) {
  try {
    switch (actions.doc) {
      case SELF:
        yield call(loading);
        var services = "users";
        var response = yield call(
          graphql.search,
          services,
          actions.obj ? actions.obj.skip : 0,
          actions.obj ? actions.obj.limit : 10,
          url,
          actions
        );
        var users = response.data.data.users;
        yield put({
          type: USER_API.SELF.ALL.SUCCESS,
          data: users
        });
        if (users.length == 0) {
          return yield call(outOfRange);
        } else {
          return yield call(complete);
        }
      case STAT:
        try {
          yield call(loading);
          const me = yield call(graphql.get, "me", "account", {
            query: query.auth.me
          });
          var items = actions.item;
          if (roles.permission(me.data.data.me.roles, ["ADMIN"])) {
            items = { ...items, roles: "STUDENT" };
          } else if (roles.permission(me.data.data.me.roles, ["TEACHER"])) {
            items = {
              ...items,
              roles: "STUDENT",
              advisorId: me.data.data.me.username
            };
          } else if (roles.permission(me.data.data.me.roles, ["INSTITUTE"])) {
            items = {
              ...items,
              roles: "STUDENT",
              instituteId: { $oid: me.data.data.me.institute.id }
            };
          } else {
            return;
          }
          var response = yield call(
            graphql.search,
            "users",
            actions.obj ? actions.obj.skip : 0,
            actions.obj ? actions.obj.limit : 10,
            url,
            { ...actions, item: { ...items } }
          );
          yield put({
            type: USER_API.STAT.ALL.SUCCESS,
            data: response.data.data.users
          });
          if (response.data.data.users.length == 0) {
            yield put({
              type: USER_API.SELF.CALLBACK_OUT.SUCCESS
            });
            return yield call(outOfRange);
          } else {
            return yield call(complete);
          }
        } catch (e) {
          console.log(e);
        }
      case PREDEFINED:
        yield call(loading);
        var response = yield call(
          graphql.search,
          "predefinedAccounts",
          actions.obj ? actions.obj.skip : 0,
          actions.obj ? actions.obj.limit : 10,
          url,
          actions
        );
        var users = response.data.data.predefinedAccounts;
        yield put({
          type: USER_API.PREDEFINED.ALL.SUCCESS,
          data: users
        });
        if (users.length == 0) {
          return yield call(outOfRange);
        } else {
          return yield call(complete);
        }
      case SIGNUP:
        yield call(loading);
        var services = "signUps";
        var response = yield call(
          graphql.search,
          services,
          actions.obj ? actions.obj.skip : 0,
          actions.obj ? actions.obj.limit : 10,
          url,
          actions
        );
        var users = response.data.data.signUps;
        yield put({
          type: USER_API.SIGNUP.ALL.SUCCESS,
          data: users
        });
        if (users.length == 0) {
          return yield call(outOfRange);
        } else {
          return yield call(complete);
        }
      case INSTITUTE:
        yield call(loading);
        if (actions.obj) {
          if (actions.obj.isRest) {
            var response = yield call(
              graphql.getRest,
              "/account/institutes",
              actions.item
            );
            return yield put({
              type: USER_API.INSTITUTE.ALL.SUCCESS,
              data: response.data
            });
          }
        }
        var response = yield call(
          graphql.search,
          "institutes",
          actions.obj ? actions.obj.skip : 0,
          actions.obj ? actions.obj.limit : 10,
          url,
          actions
        );
        var institutes = response.data.data.institutes;
        yield put({
          type: USER_API.INSTITUTE.ALL.SUCCESS,
          data: institutes
        });
        if (institutes.length == 0) {
          yield put({
            type: USER_API.INSTITUTE.CALLBACK_OUT.SUCCESS
          });
          return yield call(outOfRange);
        } else {
          return yield call(complete);
        }
      default:
        null;
    }
  } catch (e) {
    console.log(e);
    //yield call(callback, false, e);
  }
}
function* get(actions) {
  try {
    switch (actions.doc) {
      case ME:
        var response = yield call(graphql.get, "me", "account", actions);
        if (response.data) {
          return yield put({
            type: USER_API.ME.GET.SUCCESS,
            data: response.data.data.me
          });
        } else {
          return yield call({ type: REDIRECT_TO, redirectTo: "/login" });
        }
      case SELF:
        var response = yield call(user.getUser, actions.id);
        return yield put({
          type: USER_API.SELF.GETID.SUCCESS,
          data: response.data
        });
        return yield call(callback, true);
      case PREDEFINED:
        var response = yield call(
          graphql.get,
          `predefinedAccount(id:"${actions.id}")`,
          url,
          actions
        );
        return yield put({
          type: USER_API.PREDEFINED.GET.SUCCESS,
          data: response.data.data.predefinedAccount
        });
        return yield call(callback, true);
      case SIGNUP:
        var response = yield call(user.getPending, actions.id);
        return yield put({
          type: USER_API.SIGNUP.GET.SUCCESS,
          data: response.data
        });
        return yield call(callback, true);
      case VERIFY:
        yield call(loading);
        var response = yield call(user.getVerify, actions.item);
        yield put({
          type: USER_API.VERIFY.GET.SUCCESS,
          data: response.data
        });
        return yield call(callback, true);
      case VERIFY_CODE:
        yield call(loading);
        var response = yield call(user.getVerifyCode, actions.id);
        yield put({
          type: USER_API.VERIFY_CODE.GET.SUCCESS,
          data: response.data
        });
        return yield call(callback, true);
      default:
        null;
    }
  } catch (e) {
    console.log(e);
    if (actions.doc === "ME") {
      yield put({
        type: REDIRECT_TO,
        redirectTo: "/login"
      });
    } else {
      yield call(callback, false, e);
    }
  }
}
function* post(actions) {
  try {
    switch (actions.doc) {
      case SELF:
        var response = yield call(user.postUser, actions.item);
        yield put({
          type: USER_API.SELF.POST.SUCCESS,
          data: response.data
        });
        yield call(callback, true);
        return yield put({
          type: REDIRECT_TO,
          redirectTo: "/user"
        });
      case SIGNUP:
        var response = yield call(user.signup, actions.item);
        yield put({
          type: USER_API.SIGNUP.POST.SUCCESS,
          data: response.data
        });
        yield call(callback, true);
        return yield put({
          type: REDIRECT_TO,
          redirectTo: "/login"
        });
      case EXTERNAL_SIGNUP:
        var response = yield call(user.externalSignup, actions.item);
        yield put({
          type: USER_API.EXTERNAL_SIGNUP.POST.SUCCESS,
          data: response.data
        });
        call(callback, true);
        return yield put({
          type: REDIRECT_TO,
          redirectTo: "/"
        });
      case VERIFY:
        var response = yield call(user.signupVerify, actions.item);
        yield put({
          type: USER_API.VERIFY.POST.SUCCESS,
          data: response.data
        });
        return yield call(callback, true);
      case FORGOT:
        var response = yield call(
          graphql.import,
          `/account/password/forgot/${actions.item.username}`,
          actions.item
        );
        yield put({
          type: USER_API.FORGOT.POST.SUCCESS,
          data: response.data
        });
        yield call(callback, true);
        return history.back();
      case RESET:
        var response = yield call(
          graphql.import,
          `/account/password/reset?resetKey=${actions.item.resetKey}`,
          `${actions.item.password}`
        );
        yield put({
          type: USER_API.RESET.POST.SUCCESS,
          data: response.data
        });
        yield call(callback, true);
        return yield put({
          type: REDIRECT_TO,
          redirectTo: "/login"
        });
      case IMPORT:
        var response = yield call(
          graphql.graph,
          `mutation{
  insertUserMany(roles:["${actions.obj.role}"],specialtyId:"${
            actions.obj.specialtyId
          }",users:${convert(actions.item)}){
    problem
    user{
      username

      email
      titleTh
      firstNameTh
      lastNameTh
      titleEn
      firstNameEn
      lastNameEn
      gender
      phoneNumber
      yearEnrolled
    }
  }
}`,
          {},
          url,
          actions
        );
        yield put({
          type: USER_API.IMPORT.POST.SUCCESS,
          data: response.data.data.insertUserMany
        });
        return yield call(callback, true);

      default:
        null;
    }
  } catch (e) {
    console.log(e);
    yield call(callback, false, e);
  }
}
function* change(actions) {
  try {
    switch (actions.doc) {
      case SELF:
        var response = yield call(user.putUser, actions.id, actions.item);
        yield put({
          type: USER_API.SELF.PUT.SUCCESS,
          data: response.data
        });
        yield put({
          type: USER_API.ME.GET.SUCCESS,
          data: response.data
        });
        return yield call(callback, true);
      case SIGNUP:
        var response = yield call(user.putPending, actions.id, actions.item);
        yield put({
          type: USER_API.SIGNUP.PUT.SUCCESS,
          data: response.data
        });
        yield call(callback, true);
        return yield put({
          type: REDIRECT_TO,
          redirectTo: "/user/pending"
        });
      case PREDEFINED:
        var response = yield call(
          graphql.put,
          `PredefinedAccount`,
          url,
          actions
        );
        yield put({
          type: USER_API.PREDEFINED.PUT.SUCCESS,
          data: response.data
        });
        return yield call(callback, true);
      case PASSWORD:
        var response = yield call(
          graphql.postRest,
          `/account/password/change/${actions.id}`,
          actions.item
        );
        yield put({
          type: USER_API.PASSWORD.PUT.SUCCESS,
          data: response.data
        });
        yield call(callback, true);
        return history.back();
      default:
        null;
    }
  } catch (e) {
    console.log(e);
    yield call(callback, false, e);
  }
}
function* del(actions) {
  try {
    switch (actions.doc) {
      case SELF:
        var response = yield call(user.delUser, actions.id);
        yield put({
          type: USER_API.SELF.DEL.SUCCESS,
          data: actions.id
        });
        yield call(callback, true);
        return yield put({
          type: REDIRECT_TO,
          redirectTo: "/user"
        });
      case SIGNUP:
        var response = yield call(user.delPending, actions.id);
        yield put({
          type: USER_API.SIGNUP.DEL.SUCCESS,
          data: actions.id
        });
        yield call(callback, true);
        return yield put({
          type: REDIRECT_TO,
          redirectTo: "/user/pending"
        });
      case PREDEFINED:
        var response = yield call(
          graphql.delete,
          `PredefinedAccount`,
          url,
          actions
        );
        yield put({
          type: USER_API.PREDEFINED.DEL.SUCCESS,
          data: actions.id
        });
        yield call(callback, true);
        return yield put({
          type: REDIRECT_TO,
          redirectTo: "/user/nonMember"
        });
      default:
        null;
    }
  } catch (e) {
    console.log(e);
    yield call(callback, false, e);
  }
}
function* search(actions) {
  try {
    switch (actions.doc) {
      case SELF:
        var response = yield call(
          graphql.search,
          "users",
          actions.item.skip,
          actions.obj ? (actions.obj.limit ? actions.obj.limit : 30) : 30,
          "account",
          actions
        );
        return yield put({
          type: USER_API.SELF.SEARCH.SUCCESS,
          data: response.data.data.users
        });
      case INSTITUTE:
        var response = yield call(
          graphql.search,
          "instituteUsers",
          actions.item.skip,
          actions.obj ? (actions.obj.limit ? actions.obj.limit : 30) : 30,
          "account",
          actions
        );
        return yield put({
          type: USER_API.SELF.SEARCH.SUCCESS,
          data: response.data.data.instituteUsers
        });
      default:
        null;
    }
  } catch (e) {
    console.log(e);
    yield call(callback, false, e);
  }
}
export function* watchUser() {
  yield takeEvery(USER_REQUEST, request);
}
